;; Generated package description from sotlisp.el  -*- no-byte-compile: t -*-
(define-package "sotlisp" "1.6.2" "Write lisp at the speed of thought." '((emacs "24.1")) :commit "fffe8d0b42b143a2e7df0470d9049fa57b6ecac5" :authors '(("Artur Malabarba" . "emacs@endlessparentheses.com")) :maintainer '("Artur Malabarba" . "emacs@endlessparentheses.com") :keywords '("convenience" "lisp") :url "https://github.com/Malabarba/speed-of-thought-lisp")
